@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2018 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2019 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -144,6 +144,7 @@ public slots:
 	virtual void loadAudioFile(); // Load external audio file
 
 	void setInitialSubtitle(const QString & subtitle_file);
+	void setInitialSecond(int second);
 
 #ifdef FIND_SUBTITLES
 	virtual void showFindSubtitlesDialog();
@@ -616,8 +617,11 @@ protected:
 	MyAction * incSaturationAct;
 	MyAction * decGammaAct;
 	MyAction * incGammaAct;
+	MyAction * prevVideoAct;
 	MyAction * nextVideoAct;
+	MyAction * prevAudioAct;
 	MyAction * nextAudioAct;
+	MyAction * prevSubtitleAct;
 	MyAction * nextSubtitleAct;
 	MyAction * nextChapterAct;
 	MyAction * prevChapterAct;
