@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2018 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2019 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -58,6 +58,7 @@
 
 #ifndef NO_SMPLAYER_SUPPORT
 #include "images.h"
+#include "filedialog.h"
 #endif
 
 #define COL_LANG 0
@@ -83,6 +84,9 @@ FindSubtitlesWindow::FindSubtitlesWindow( QWidget * parent, Qt::WindowFlags f )
 	connect( file_chooser, SIGNAL(textChanged(const QString &)),
              this, SLOT(updateRefreshButton()) );
 
+	connect( search_edit, SIGNAL(returnPressed()), this, SLOT(searchTitle()) );
+	connect( search_title_button, SIGNAL(clicked()), this, SLOT(searchTitle()) );
+
 	connect( refresh_button, SIGNAL(clicked()),
              this, SLOT(refresh()) );
 
@@ -301,7 +305,7 @@ void FindSubtitlesWindow::retranslateStrings() {
 }
 
 void FindSubtitlesWindow::setMovie(QString filename) {
-	qDebug("FindSubtitlesWindow::setMovie: '%s'", filename.toLatin1().constData());
+	qDebug() << "FindSubtitlesWindow::setMovie:" << filename;
 
 	if (filename == last_file) {
 		return;
@@ -318,11 +322,28 @@ void FindSubtitlesWindow::setMovie(QString filename) {
 		qint64 file_size = fi.size();
 		QString basename;
 		basename = fi.completeBaseName(); // Filename without extension
+		search_edit->setText(basename);
 		osclient->search(hash, file_size, basename);
 		last_file = filename;
 	}
 }
 
+void FindSubtitlesWindow::searchTitle() {
+	QString t = search_edit->text();
+	qDebug() << "FindSubtitlesWindow::searchTitle:" << t;
+
+	if (osclient->searchMethod() != OSClient::Hash) {
+		osclient->search("", 0, t);
+	}
+}
+
+void FindSubtitlesWindow::updateSearchTitleWidget() {
+	bool title_search_allowed = (osclient->searchMethod() != OSClient::Hash);
+	search_for_label->setEnabled(title_search_allowed);
+	search_edit->setEnabled(title_search_allowed);
+	search_title_button->setEnabled(title_search_allowed);
+}
+
 void FindSubtitlesWindow::refresh() {
 	last_file = "";
 	setMovie(file_chooser->text());
@@ -532,28 +553,46 @@ void FindSubtitlesWindow::archiveDownloaded(const QByteArray & buffer) {
 		extension = table->item(proxy_model->mapToSource(index).row(), COL_FORMAT)->text();
 	}
 
-	QFileInfo fi(file_chooser->text());
-	QString output_name = fi.completeBaseName();
-	if (include_lang_on_filename) output_name += "_"+ lang;
-	output_name += "." + extension;
+	QString output_file;
 
-	QString output_file = fi.absolutePath() + "/" + output_name;
-	qDebug("FindSubtitlesWindow::archiveDownloaded: save subtitle as '%s'", output_file.toUtf8().constData());
+	if (!file_chooser->text().isEmpty() && QFile::exists(file_chooser->text())) {
+		QFileInfo fi(file_chooser->text());
+		QString output_name = fi.completeBaseName();
+		if (include_lang_on_filename) output_name += "_"+ lang;
+		output_name += "." + extension;
 
-	QFile file(output_file);
-	file.open(QIODevice::WriteOnly);
-	bool error = (file.write(uncompress_data) == -1);
-	file.close();
+		output_file = fi.absolutePath() + "/" + output_name;
+		qDebug() << "FindSubtitlesWindow::archiveDownloaded: save subtitle as" << output_file;
+	}
 
-	if (error) {
-		qWarning("FindSubtitlesWindow::archiveDownloaded: can't write subtitle file");
-		QMessageBox::warning(this, tr("Error saving file"),
+	if (output_file.isEmpty()) {
+		QString output_name = "subtitle";
+		if (!search_edit->text().isEmpty()) output_name = search_edit->text();
+		if (include_lang_on_filename) output_name += "_"+ lang;
+		output_name += "." + extension;
+		#ifndef NO_SMPLAYER_SUPPORT
+		output_file = MyFileDialog::getSaveFileName(this, tr("Save File"), output_name);
+		#else
+		output_file = QFileDialog::getSaveFileName(this, tr("Save File"), output_name);
+		#endif
+	}
+
+	if (!output_file.isEmpty()) {
+		QFile file(output_file);
+		file.open(QIODevice::WriteOnly);
+		bool error = (file.write(uncompress_data) == -1);
+		file.close();
+
+		if (error) {
+			qWarning("FindSubtitlesWindow::archiveDownloaded: can't write subtitle file");
+			QMessageBox::warning(this, tr("Error saving file"),
                              tr("It wasn't possible to save the downloaded\n"
                                 "file in folder %1\n"
-                                "Please check the permissions of that folder.").arg(fi.absolutePath()));
-	} else {
-		status->setText(tr("Subtitle saved as %1").arg(output_file));
-		emit subtitleDownloaded( output_file );
+                                "Please check the permissions of that folder.").arg(QFileInfo(output_file).absolutePath()));
+		} else {
+			status->setText(tr("Subtitle saved as %1").arg(output_file));
+			emit subtitleDownloaded( output_file );
+		}
 	}
 }
 
@@ -841,6 +880,8 @@ void FindSubtitlesWindow::on_configure_button_clicked() {
 		include_lang_on_filename = d.appendLang();
 		#endif
 	}
+
+	updateSearchTitleWidget();
 }
 
 #ifdef FS_USE_PROXY
@@ -923,6 +964,8 @@ void FindSubtitlesWindow::loadSettings() {
 	osclient->setSearchMethod( (OSClient::SearchMethod) set->value("search_method", osclient->searchMethod()).toInt() );
 
 	set->endGroup();
+
+	updateSearchTitleWidget();
 }
 
 #include "moc_findsubtitleswindow.cpp"
