@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2018 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2019 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -63,7 +63,8 @@ void MPVProcess::setMedia(const QString & media, bool is_playlist) {
 	arg << "--term-playing-msg="
 			"MPV_VERSION=${=mpv-version:}\n"
 			"INFO_VIDEO_WIDTH=${=width}\nINFO_VIDEO_HEIGHT=${=height}\n"
-			"INFO_VIDEO_ASPECT=${=video-aspect}\n"
+//			"INFO_VIDEO_ASPECT=${=video-aspect}\n" // old
+			"INFO_VIDEO_ASPECT=${=video-params/aspect}\n"
 //			"INFO_VIDEO_DSIZE=${=dwidth}x${=dheight}\n"
 			"INFO_VIDEO_FPS=${=container-fps:${=fps}}\n"
 //			"INFO_VIDEO_BITRATE=${=video-bitrate}\n"
@@ -128,6 +129,7 @@ void MPVProcess::setFixedOptions() {
 	//arg << "--no-osc";
 	//arg << "--msg-level=vd=v";
 	//arg << "--video-stereo-mode=no";
+	arg << "--msg-level=ffmpeg/demuxer=error";
 }
 
 void MPVProcess::disableInput() {
@@ -199,7 +201,12 @@ void MPVProcess::setOption(const QString & option_name, const QVariant & value)
 	if (option_name == "cache") {
 		int cache = value.toInt();
 		if (cache > 31) {
-			arg << "--cache=" + value.toString();
+			if (isOptionAvailable("--demuxer-max-bytes")) {
+				int bytes = value.toString().toInt() * 1024;
+				arg << "--demuxer-max-bytes=" + QString::number(bytes);
+			} else {
+				arg << "--cache=" + value.toString();
+			}
 		} else {
 			arg << "--cache=no";
 		}
@@ -1183,6 +1190,13 @@ void MPVProcess::setSubStyles(const AssStyles & styles, const QString &) {
 	SUBOPTION(sub_align_x, "--sub-align-x", "--sub-text-align-x");
 	SUBOPTION(sub_align_y, "--sub-align-y", "--sub-text-align-y");
 
+	QString sub_margin_y = "";
+	if (isOptionAvailable("--sub-margin-y")) sub_margin_y = "--sub-margin-y";
+
+	QString sub_margin_x = "";
+	if (isOptionAvailable("--sub-margin-x")) sub_margin_x = "--sub-margin-x";
+
+
 	if (!sub_font.isEmpty()) {
 		QString font = styles.fontname;
 		//arg << "--sub-text-font=" + font.replace(" ", "");
@@ -1238,10 +1252,22 @@ void MPVProcess::setSubStyles(const AssStyles & styles, const QString &) {
 	if (!sub_align_x.isEmpty() && !halign.isEmpty()) {
 		arg << sub_align_x + "=" + halign;
 	}
-	
+
 	if (!sub_align_y.isEmpty() && !valign.isEmpty()) {
 		arg << sub_align_y + "=" + valign;
 	}
+
+	if (!sub_margin_y.isEmpty()) {
+		int marginv = styles.marginv;
+		if (marginv < 0) marginv = 0;
+		arg << sub_margin_y + "=" + QString::number(marginv);
+	}
+
+	if (!sub_margin_x.isEmpty()) {
+		int marginx = styles.marginl;
+		if (marginx < 0) marginx = 0;
+		arg << sub_margin_x + "=" + QString::number(marginx);
+	}
 }
 
 void MPVProcess::setChannelsFile(const QString & filename) {
